@@ -1,7 +1,7 @@
 # ABSTRACT: Simple way to access Cassandra 0.7
 package Cassandra::Lite;
 BEGIN {
-  $Cassandra::Lite::VERSION = '0.0.1';
+  $Cassandra::Lite::VERSION = '0.0.2';
 }
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ Cassandra::Lite - Simple way to access Cassandra 0.7
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 DESCRIPTION
 
@@ -53,8 +53,8 @@ You'll need to install Thrift and Cassandra perl modules first to use Cassandra:
     # Change keyspace
     $c->keyspace('BlogArticleComment');
 
-    # Count
-    my $num = $c->count('Foo', 'key1');
+    # Get count
+    my $num = $c->get_count('Foo', 'key1');
 
     ...
 
@@ -123,10 +123,25 @@ sub _trigger_keyspace {
     $self->client->set_keyspace($keyspace);
 }
 
-=head2 FUNCTION count
+=head2 get
 =cut
 
-sub count {
+sub get {
+    my $self = shift;
+
+    my $columnFamily = shift;
+    my $key = shift;
+    my $column = shift;
+
+    my $columnPath = Cassandra::ColumnPath->new({column_family => $columnFamily, column => $column});
+
+    $self->client->get($key, $columnPath);
+}
+
+=head2 get_count
+=cut
+
+sub get_count {
     my $self = shift;
 
     my $columnFamily = shift;
@@ -148,25 +163,10 @@ sub count {
     my $predicate = Cassandra::SlicePredicate->new;
     $predicate->{slice_range} = $sliceRange;
 
-    $self->client->count($key, $columnParent, $predicate);
+    $self->client->get_count($key, $columnParent, $predicate);
 }
 
-=head2 FUNCTION get
-=cut
-
-sub get {
-    my $self = shift;
-
-    my $columnFamily = shift;
-    my $key = shift;
-    my $column = shift;
-
-    my $columnPath = Cassandra::ColumnPath->new({column_family => $columnFamily, column => $column});
-
-    $self->client->get($key, $columnPath);
-}
-
-=head2 FUNCTION get_slice
+=head2 get_slice
 =cut
 
 sub get_slice {
@@ -194,7 +194,7 @@ sub get_slice {
     $self->client->get_slice($key, $columnParent, $predicate);
 }
 
-=head2 FUNCTION insert
+=head2 insert
 =cut
 
 sub insert {
@@ -219,7 +219,7 @@ sub insert {
     $self->client->insert($key, $columnParent, $column);
 }
 
-=head2 FUNCTION remove
+=head2 remove
 =cut
 
 sub remove {
